@@ -12,9 +12,6 @@ var Output *os.File
 
 func InitializeFileLogger() {
 	path := filepath.Join(config.OctosqlCacheDir, "logs.txt")
-	if err := os.MkdirAll(config.OctosqlCacheDir, 0755); err != nil {
-		log.Fatalf("couldn't create ~/.octosql home directory: %s", err)
-	}
 	f, err := os.Create(path)
 	if err != nil {
 		log.Fatalf("couldn't create logs file: %s", err)
